from django import forms
from django.conf import settings
from django.core.urlresolvers import reverse
from django.utils.safestring import mark_safe
from django.utils.html import conditional_escape
from django.utils.encoding import force_unicode
from django.utils import simplejson
from django.middleware.csrf import get_token
from django.core.exceptions import ImproperlyConfigured
from django.forms.util import flatatt



class CLEditorWidget(forms.Textarea):
    """
    Widget providing CLEditor for Rich Text Editing.
    Supports direct image uploads and embed.
    """
    class Media:
        js = [
            # 'cleditor/jquery-1.7.1.min.js',
            'cleditor/jquery.cookie.js',
            'cleditor/jquery.cleditor.min.js',
        ]
        css = {
            'all': ('cleditor/jquery.cleditor.css',),
        }


    def __init__(self, config_name='default', upload=False, *args, **kwargs):
        self.upload = upload
        super(CLEditorWidget, self).__init__(*args, **kwargs)
            

    def render(self, name, value, attrs={}):
        if value is None: value = ''
        final_attrs = self.build_attrs(attrs, name=name)
        # self.config['filebrowserUploadUrl'] = reverse('ckeditor_upload')
        # self.config['filebrowserBrowseUrl'] = reverse('ckeditor_browse')
        return mark_safe(u'''<textarea{flat_attrs}>{value}</textarea>
        <script type="text/javascript">
            django.jQuery(function() {{
                django.jQuery("#{id}").cleditor();
            }})
        </script>'''.format(
            flat_attrs=flatatt(final_attrs),
            value=value,
            id=final_attrs.get('id'),
        ))

class CLEditorUploadWidget(CLEditorWidget):
    class Media:
        js = [
            # 'cleditor/jquery-1.7.1.min.js',
            'cleditor/jquery.cookie.js',
            'cleditor/jquery.cleditor.min.js',
            'cleditor/jquery.cleditor.extimage.js',
        ]
        css = {
            'all': ('cleditor/jquery.cleditor.css',),
        }

            


import os

from django import http
from django.contrib import admin
from django.conf import settings
from django.conf.urls.defaults import patterns
from django.core.files.storage import default_storage
from django.core.files.base import ContentFile
from django.views.decorators.csrf import csrf_exempt


class CLEditorUploadAdmin(admin.ModelAdmin):
	upload_to = 'cleditoruploads/'

	"""
	CLEditor Upload Admin
	---------------------
	"""
	def get_urls(self):
		urls = super(CLEditorUploadAdmin, self).get_urls()
		my_urls = patterns('',
			(r'upload-image/$', self.admin_site.admin_view(self.upload_handler)),
		)
		return my_urls + urls

	
	@csrf_exempt
	def upload_handler(self, request):
		"""
		Handle widget uploader
		"""
		if not request.POST:
			raise http.Http404

		f = request.FILES['imageName']
		result = default_storage.save(os.path.join(self.upload_to, f.name), f)
		return http.HttpResponse('<div id="image">{static_url}{path}</div>'.format(static_url=settings.STATIC_URL, path=result))


#!/usr/bin/env python
from setuptools import setup, find_packages

setup(
    name="django-cleditor",
    version='0.2.1',
    description="A django form widget for CLEditor (a super clean, MIT licensed WYSIWYG HTML editor) that handles uploading",
    long_description='',
    author="Yuji Tomita",
    author_email="yuji@yujitomita.com",
    url="https://github.com/yuchant/django-cleditor",
    packages=[
        'cleditor',
    ],
    package_dir={
      'cleditor': 'cleditor',
    },
    include_package_data=True,
    classifiers=[
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Framework :: Django",
    ]
)
